<!DOCTYPE html>
<html>
  <head>
    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8"/>
  </head>
  <body>
    <form name="mturk_form" method="post" id="mturk_form" target="_parent"
          action="{{ form_submit_url }}"
          data-iframe-height="">
      {{ !turk_template }}
      % if not turk_template_has_submit_button:
      <p class="text-center">
        <input type="submit" id="submitButton" class="btn btn-primary" value="Submit" />
      </p>
      % end
    </form>
  </body>
</html>
